@@ -761,7 +761,7 @@ public class AccessControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh_ALL();
+					FacilityTreeCache.refresh();
 					
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -823,7 +823,7 @@ public class AccessControllerBean {
 			RepositoryValidator.validateScopeInfo(null, scopeInfo, false);
 
 			// ロールスコープ更新
-			FacilityModifier.modifyScope(scopeInfo, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), false);
+			FacilityModifier.modifyOwnerRoleScope(scopeInfo, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), false);
 
 			jtm.commit();
 			commit = true;
@@ -858,7 +858,7 @@ public class AccessControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refreshInfo();
+					FacilityTreeCache.refresh();
 					
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -950,7 +950,7 @@ public class AccessControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh_ALL();
+					FacilityTreeCache.refresh();
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1133,7 +1133,7 @@ public class AccessControllerBean {
 				// ユーザロールキャッシュ情報を変更する
 				UserRoleCache.refresh();
 				// ファシリティツリーのオブジェクト権限情報をリフレッシュする
-				FacilityTreeCache.refreshTreePrivilege();
+				FacilityTreeCache.refresh();
 			}
 
 			jtm.close();
@@ -1320,7 +1320,7 @@ public class AccessControllerBean {
 				// スコープのオブジェクト権限処理の場合はファシリティツリー情報、最終更新時刻を更新する
 				if (HinemosModuleConstant.PLATFORM_REPOSITORY.equals(objectType)) {
 					RepositoryUpdateTime.refreshUpdateTime();
-					FacilityTreeCache.refreshTreePrivilege();
+					FacilityTreeCache.refresh();
 				}
 			}
 			jtm.close();
