@@ -31,6 +31,7 @@ import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.calendar.bean.CalendarDetailInfo;
 import com.clustercontrol.calendar.bean.CalendarInfo;
@@ -303,7 +304,7 @@ public class ModifyCalendar {
 				validTimeTo = new Timestamp(info.getValidTimeTo());
 			}
 			//カレンダを作成
-			CalInfoEntity entity = QueryUtil.getCalInfoPK(id);
+			CalInfoEntity entity = QueryUtil.getCalInfoPK(id, ObjectPrivilegeMode.WRITE);
 			entity.setCalendarName(name);
 			entity.setDescription(description);
 			/* 作成時刻、作成ユーザは変更時に更新されるはずがないので、再度登録しない
@@ -367,7 +368,7 @@ public class ModifyCalendar {
 			//オーナーロールIDを取得
 			String ownerRoleId = info.getOwnerRoleId();
 			//カレンダを作成
-			CalPatternInfoEntity entity = QueryUtil.getCalPatternInfoPK(id);
+			CalPatternInfoEntity entity = QueryUtil.getCalPatternInfoPK(id, ObjectPrivilegeMode.WRITE);
 			entity.setCalPatternId(id);
 			entity.setCalPatternName(name);
 			entity.setOwnerRoleId(ownerRoleId);
@@ -424,7 +425,7 @@ public class ModifyCalendar {
 
 		try {
 			//カレンダ情報を検索し取得
-			CalInfoEntity cal = QueryUtil.getCalInfoPK(id);
+			CalInfoEntity cal = QueryUtil.getCalInfoPK(id, ObjectPrivilegeMode.WRITE);
 
 			//カレンダ情報を削除
 			em.remove(cal);
@@ -455,7 +456,7 @@ public class ModifyCalendar {
 		m_log.info("deleteCalendarPattern : deleted " + id);
 		try {
 			//カレンダ[カレンダパターン]情報を検索し取得
-			CalPatternInfoEntity calPa = QueryUtil.getCalPatternInfoPK(id);
+			CalPatternInfoEntity calPa = QueryUtil.getCalPatternInfoPK(id, ObjectPrivilegeMode.WRITE);
 			//カレンダ[カレンダパターン]情報を削除
 			em.remove(calPa);
 		} catch (CalendarNotFound e) {
