@@ -15,13 +15,10 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.hinemosagent.factory;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.AddMonitor;
 import com.clustercontrol.monitor.run.factory.ModifyMonitorTruthValueType;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 /**
  * Hinemos Agent監視情報更新クラス<BR>
@@ -35,7 +32,7 @@ public class ModifyMonitorAgent extends ModifyMonitorTruthValueType{
 	 * @see com.clustercontrol.monitor.run.factory.ModifyMonitor#modifyCheckInfo()
 	 */
 	@Override
-	protected boolean modifyCheckInfo() throws CreateException, FinderException, NamingException {
+	protected boolean modifyCheckInfo() throws MonitorNotFound {
 
 		// Agent監視情報を取得
 		// Agent監視情報は監視の有無のみ。CheckInfoは存在しない。
@@ -55,7 +52,7 @@ public class ModifyMonitorAgent extends ModifyMonitorTruthValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_SIMPLE;
+	protected TriggerType getTriggerType() {
+		return TriggerType.SIMPLE;
 	}
 }
\ No newline at end of file
