@@ -16,6 +16,7 @@ package com.clustercontrol.hinemosagent.util;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.net.ConnectException;
 import java.net.DatagramPacket;
 import java.net.DatagramSocket;
 import java.net.InetAddress;
@@ -441,18 +442,21 @@ public class AgentConnectUtil {
 			}
 		}
 		// エージェントが接続するためのマネージャのIPを調べる
-		try {
-			// DNS名接続の場合(agent.connection.dnsnameに文字列が指定) Hinemos ver 4.0.2以降対応
-			managerIpAddr = HinemosProperties.getProperty("agent.connection.dnsname","");
-			
-			// IPアドレス接続の場合(agent.connection.dnsnameが未指定)
-			if(managerIpAddr == null || "".equals(managerIpAddr)){
-				managerIpAddr = HinemosProperties.getProperty(
-						"agent.connection.ipaddres", InetAddress.getLocalHost()
-						.getHostAddress());
+		// DNS名接続の場合(agent.connection.dnsnameに文字列が指定) Hinemos ver 4.0.2以降対応
+		managerIpAddr = HinemosProperties.getProperty("agent.connection.dnsname","");
+		
+		// IPアドレス接続の場合(agent.connection.dnsnameが未指定)
+		if(managerIpAddr == null || "".equals(managerIpAddr)){
+			String localAddress = "";
+			try {
+				localAddress = InetAddress.getLocalHost().getHostAddress();
+			} catch (Exception e) {
+				localAddress = "";
+				if (m_log.isDebugEnabled()) {
+					m_log.debug("sendManagerDiscoveryInfo() : can't resolve localhost. ", e);
+				}
 			}
-		} catch (UnknownHostException e) {
-			throw e;
+			managerIpAddr = HinemosProperties.getProperty("agent.connection.ipaddres", localAddress);
 		}
 
 		// FIXME 本関数内の処理では通信のタイムアウトなどを設けていないため、異常な応答などが返った場合に無限待ちとなる可能性がある
@@ -491,6 +495,10 @@ public class AgentConnectUtil {
 				totalBytesRcvd += bytesRcvd;
 			}
 			m_log.info("received the message: " + new String(msg));
+		} catch (ConnectException e) {
+			successFlag = false;
+			m_log.warn("facilityId: " + facilityId + ", " + e.getMessage());
+			m_log.debug("facilityId: " + facilityId + ", " + e.getMessage(),e);
 		} catch (Exception e) {
 			successFlag = false;
 			m_log.warn("facilityId: " + facilityId + ", " + e.getMessage(),e);
