@@ -1,6 +1,6 @@
 /*
 
- Copyright (C) 2006 NTT DATA Corporation
+ Copyright (C) 2013 NTT DATA Corporation
 
  This program is free software; you can redistribute it and/or
  Modify it under the terms of the GNU General Public License
@@ -23,10 +23,11 @@ import javax.xml.bind.annotation.XmlType;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RunIntervalConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.calendar.bean.CalendarDTO;
+import com.clustercontrol.calendar.bean.CalendarInfo;
 import com.clustercontrol.custom.bean.CustomCheckInfo;
 import com.clustercontrol.http.bean.HttpCheckInfo;
 import com.clustercontrol.logfile.bean.LogfileCheckInfo;
+import com.clustercontrol.monitor.plugin.bean.PluginCheckInfo;
 import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.performance.monitor.bean.PerfCheckInfo;
 import com.clustercontrol.ping.bean.PingCheckInfo;
@@ -35,6 +36,7 @@ import com.clustercontrol.process.bean.ProcessCheckInfo;
 import com.clustercontrol.snmp.bean.SnmpCheckInfo;
 import com.clustercontrol.snmptrap.bean.TrapCheckInfo;
 import com.clustercontrol.sql.bean.SqlCheckInfo;
+import com.clustercontrol.winevent.bean.WinEventCheckInfo;
 import com.clustercontrol.winservice.bean.WinServiceCheckInfo;
 
 /**
@@ -42,7 +44,7 @@ import com.clustercontrol.winservice.bean.WinServiceCheckInfo;
  * jaxbで利用するため、引数なしのコンストラクタが必要。
  * そのため、abstractにしない。
  * 
- * @version 4.0.0
+ * @version 4.1.0
  * @since 2.0.0
  */
 @XmlType(namespace = "http://monitor.ws.clustercontrol.com")
@@ -84,7 +86,7 @@ implements java.io.Serializable
 	private String m_calendarId;
 
 	/** カレンダ(エージェントにMonitorInfoを送る時以外はnull) */
-	private CalendarDTO m_calendarDTO;
+	private CalendarInfo m_calendarInfo;
 
 	/**
 	 * 値失敗時の重要度。
@@ -134,6 +136,9 @@ implements java.io.Serializable
 	/** 収集値単位。 */
 	private String m_measure;
 
+	/** オーナーロールID */
+	private String m_ownerRoleId;
+
 	/**
 	 * 判定情報。
 	 * {@link com.clustercontrol.monitor.run.bean.MonitorJudgementInfo}のリスト。
@@ -155,7 +160,9 @@ implements java.io.Serializable
 	private CustomCheckInfo customCheckInfo;
 	private LogfileCheckInfo logfileCheckInfo;
 	private WinServiceCheckInfo winServiceCheckInfo;
-
+	private WinEventCheckInfo winEventCheckInfo;
+	private PluginCheckInfo pluginCheckInfo; 
+	
 	/**
 	 * コンストラクタ。
 	 */
@@ -186,6 +193,7 @@ implements java.io.Serializable
 	 * @param collector_flg 収集有効/無効
 	 * @param itemName 収集値表示名
 	 * @param measure 収集値単位
+	 * @param ownerRoleId オーナーロールID
 	 */
 	public MonitorInfo(
 			String application,
@@ -201,13 +209,14 @@ implements java.io.Serializable
 			String regUser,
 			int runInterval,
 			String notifyGroupId,
-			Collection notifyId,
+			Collection<NotifyRelationInfo> notifyId,
 			long updateDate,
 			String updateUser,
 			int monitor_flg,
 			int collector_flg,
 			String itemName,
 			String measure,
+			String ownerRoleId,
 
 			ArrayList<MonitorNumericValueInfo> numericValueInfo,
 			ArrayList<MonitorStringValueInfo> stringValueInfo,
@@ -217,6 +226,7 @@ implements java.io.Serializable
 			HttpCheckInfo httpCheckInfo,
 			PerfCheckInfo perfCheckInfo,
 			PingCheckInfo pingCheckInfo,
+			PluginCheckInfo pluginCheckInfo,
 			PortCheckInfo portCheckInfo,
 			ProcessCheckInfo processCheckInfo,
 			SnmpCheckInfo snmpCheckInfo,
@@ -224,7 +234,8 @@ implements java.io.Serializable
 			TrapCheckInfo trapCheckInfo,
 			CustomCheckInfo commandCheckInfo,
 			LogfileCheckInfo logfileCheckInfo,
-			WinServiceCheckInfo winServiceCheckInfo){
+			WinServiceCheckInfo winServiceCheckInfo,
+			WinEventCheckInfo winEventCheckInfo){
 
 		// 共通監視設定
 		setApplication(application);
@@ -247,6 +258,7 @@ implements java.io.Serializable
 		setCollectorFlg(collector_flg);
 		setItemName(itemName);
 		setMeasure(measure);
+		setOwnerRoleId(ownerRoleId);
 
 		// 判定情報
 		setNumericValueInfo(numericValueInfo);
@@ -258,6 +270,7 @@ implements java.io.Serializable
 		setHttpCheckInfo(httpCheckInfo);
 		setPerfCheckInfo(perfCheckInfo);
 		setPingCheckInfo(pingCheckInfo);
+		setPluginCheckInfo(pluginCheckInfo);
 		setPortCheckInfo(portCheckInfo);
 		setProcessCheckInfo(processCheckInfo);
 		setSnmpCheckInfo(snmpCheckInfo);
@@ -266,6 +279,7 @@ implements java.io.Serializable
 		setCustomCheckInfo(commandCheckInfo);
 		setLogfileCheckInfo(logfileCheckInfo);
 		setWinServiceCheckInfo(winServiceCheckInfo);
+		setWinEventCheckInfo(winEventCheckInfo);
 	}
 
 	/**
@@ -304,6 +318,7 @@ implements java.io.Serializable
 		setHttpCheckInfo(otherData.getHttpCheckInfo());
 		setPerfCheckInfo(otherData.getPerfCheckInfo());
 		setPingCheckInfo(otherData.getPingCheckInfo());
+		setPluginCheckInfo(otherData.getPluginCheckInfo());
 		setPortCheckInfo(otherData.getPortCheckInfo());
 		setProcessCheckInfo(otherData.getProcessCheckInfo());
 		setSnmpCheckInfo(otherData.getSnmpCheckInfo());
@@ -376,8 +391,8 @@ implements java.io.Serializable
 	 * エージェントにMonitorInfoを送る時以外はnullとなります。
 	 * @return
 	 */
-	public CalendarDTO getCalendarDTO() {
-		return m_calendarDTO;
+	public CalendarInfo getCalendar() {
+		return m_calendarInfo;
 	}
 
 	/**
@@ -385,8 +400,8 @@ implements java.io.Serializable
 	 * エージェントにMonitorInfoを送る時以外はnullとなります。
 	 * @param calendarDTO
 	 */
-	public void setCalendarDTO(CalendarDTO calendarDTO) {
-		this.m_calendarDTO = calendarDTO;
+	public void setCalendar(CalendarInfo calendarDTO) {
+		this.m_calendarInfo = calendarDTO;
 	}
 
 	/**
@@ -685,6 +700,24 @@ implements java.io.Serializable
 		m_measure = measure;
 	}
 
+	/**
+	 * オーナーロールIDを返します。
+	 * 
+	 * @return オーナーロールID
+	 */
+	public String getOwnerRoleId() {
+		return m_ownerRoleId;
+	}
+
+	/**
+	 * オーナーロールIDを設定します。
+	 * 
+	 * @param ownerRoleId オーナーロールID
+	 */
+	public void setOwnerRoleId(String ownerRoleId) {
+		this.m_ownerRoleId = ownerRoleId;
+	}
+
 	/**
 	 * 監視種別を返します。
 	 * 
@@ -850,4 +883,20 @@ implements java.io.Serializable
 	public void setWinServiceCheckInfo(WinServiceCheckInfo winServiceCheckInfo) {
 		this.winServiceCheckInfo = winServiceCheckInfo;
 	}
+
+	public WinEventCheckInfo getWinEventCheckInfo() {
+		return winEventCheckInfo;
+	}
+
+	public void setWinEventCheckInfo(WinEventCheckInfo winEventCheckInfo) {
+		this.winEventCheckInfo = winEventCheckInfo;
+	}
+
+	public PluginCheckInfo getPluginCheckInfo() {
+		return pluginCheckInfo;
+	}
+
+	public void setPluginCheckInfo(PluginCheckInfo pluginCheckInfo) {
+		this.pluginCheckInfo = pluginCheckInfo;
+	}
 }
