@@ -48,6 +48,7 @@ import com.clustercontrol.jobmanagement.session.JobControllerBean;
 import com.clustercontrol.jobmanagement.util.JobMultiplicityCache;
 import com.clustercontrol.monitor.session.MonitorControllerBean;
 import com.clustercontrol.notify.session.NotifyControllerBean;
+import com.clustercontrol.poller.PollingController;
 import com.clustercontrol.repository.bean.AgentStatusInfo;
 import com.clustercontrol.repository.bean.FacilityInfo;
 import com.clustercontrol.repository.bean.FacilitySortOrderConstant;
@@ -1017,6 +1018,7 @@ public class RepositoryControllerBean {
 	 */
 	public void modifyNode(NodeInfo info) throws InvalidSetting, InvalidRole, HinemosUnknown {
 		boolean commit = false;
+		boolean changeNotifySkipPeriod = false;
 
 		JpaTransactionManager jtm = null;
 
@@ -1033,6 +1035,11 @@ public class RepositoryControllerBean {
 
 			/** メイン処理 */
 			FacilityModifier.modifyNode(info, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), true);
+			
+			// 管理対象フラグが無効→有効となった場合、通知スキップ時刻の変更を行う
+			if (info.isValid() == true && this.getNode(info.getFacilityId()).isValid() == false) {
+				changeNotifySkipPeriod = true;
+			}
 
 			jtm.commit();
 			commit = true;
@@ -1068,6 +1075,14 @@ public class RepositoryControllerBean {
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
+					
+					// 管理対象フラグが無効→有効となった場合、通知をスキップする時間を変更する
+					if (changeNotifySkipPeriod == true) {
+						PollingController.setLastPollingSkipTime(info.getFacilityId());
+						if (m_log.isDebugEnabled()) {
+							m_log.debug("modifyNode() : call PollingController.setLastPollingSkipTime. facilityId = " + info.getFacilityId());
+						}
+					}
 				} catch (Exception e) {
 					m_log.warn("modifyNode() transaction failure."
 							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
@@ -1112,7 +1127,7 @@ public class RepositoryControllerBean {
 
 			checkIsUseFacility(facilityId);
 			FacilityModifier.deleteNode(facilityId, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), true);
-
+			
 			jtm.commit();
 			commit = true;
 		} catch (FacilityNotFound e) {
@@ -1142,6 +1157,12 @@ public class RepositoryControllerBean {
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
+					
+					// 通知のスキップ時刻を持ったキャッシュをクリア
+					PollingController.removeLastPollingSkipTime(facilityId);
+					if(m_log.isDebugEnabled()) {
+						m_log.debug("NotifySkipControlCallback() : call PollingController.removeLastPollingSkipTime. facilityId = " + facilityId);
+					}
 				} catch (Exception e) {
 					m_log.warn("deleteNode() transaction failure."
 							+ e.getClass().getSimpleName() +", " + e.getMessage(), e);
