@@ -27,7 +27,6 @@ HOST=`hostname`
 DBPORT=24001
 DBUSER=hinemos
 DBNAME=hinemos
-DBPASSWORD=hinemos
 
 MODE=CLUSTER
 
@@ -69,7 +68,7 @@ function usage {
 # SHELL
 ########################################
 
-# help chekc
+# help check
 for OPT in $@
 do
 	case $OPT in
@@ -92,7 +91,7 @@ do
 			MODE=CLUSTER
 			;;
 		w)
-			PASSWD=$OPTARG
+			export PGPASSWORD=${OPTARG}
 			;;
 		*)
 			ExitIllegalOptionErrorWithoutLogger
@@ -107,17 +106,20 @@ then
 	ExitIllegalArgumentError
 fi
 
+# check user
+CheckUser ${JVM_USER}
 
 # check process
-CheckJBossProcessStopped
+CheckJVMProcessStopped
 CheckPostgreSQLProcessRunning
 
 # main
-ReadPostgreSQLPasswd
+AskPostgreSQLPasswd
 
 if [ "${MODE}" = "FULLVACUUM" ]
 then
 	Logging "${MSG_I001}"
+	# -z : analyze, -f : full
 	MSG=`${PG_HOME}/bin/vacuumdb -p ${DBPORT} -U ${DBUSER} -z -f -d ${DBNAME} 2>&1`
 	RET=$?
 	
